---
name: 'Bug report'
about: 'Create a report to help us improve'
title: '[BUG]'
labels:
- bug
---

**Describe the bug**
A clear and concise description of what the bug is.

**Related issue**
(if exist)

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. Windows 10, Ubuntu Linux 18.04.01]
 - Python [e.g. 3.6, pypy3.6.9-7.3.0]
 - project version: [e.g. v0.2, commit #123456 on main]

**Test data(please attach in the report):**
A minimum test data to reproduce your problem.

**Additional context**
Add any other context about the problem here.
